@@ -8,6 +8,9 @@ Used from markdown.py
 
 from __future__ import print_function
 
+import base64
+import os
+import mimetypes
 import re
 from functools import partial
 
@@ -18,6 +21,8 @@ except ImportError:
     # Python 2
     from cgi import escape as html_escape
 
+import bs4
+
 import mistune
 
 from pygments import highlight
@@ -28,6 +33,10 @@ from pygments.util import ClassNotFound
 from nbconvert.filters.strings import add_anchor
 
 
+class InvalidNotebook(Exception):
+    pass
+
+
 class MathBlockGrammar(mistune.BlockGrammar):
     """This defines a single regex comprised of the different patterns that
     identify math content spanning multiple lines. These are used by the
@@ -128,6 +137,22 @@ class IPythonRenderer(mistune.Renderer):
         formatter = HtmlFormatter()
         return highlight(code, lexer, formatter)
 
+    def block_html(self, html):
+        embed_images = self.options.get('embed_images', False)
+
+        if embed_images:
+            html = self._html_embed_images(html)
+
+        return super().block_html(html)
+
+    def inline_html(self, html):
+        embed_images = self.options.get('embed_images', False)
+
+        if embed_images:
+            html = self._html_embed_images(html)
+
+        return super().inline_html(html)
+
     def header(self, text, level, raw=None):
         html = super().header(text, level, raw=raw)
         if self.options.get("exclude_anchor_links"):
@@ -158,12 +183,14 @@ class IPythonRenderer(mistune.Renderer):
         """
         attachments = self.options.get('attachments', {})
         attachment_prefix = 'attachment:'
+        embed_images = self.options.get('embed_images', False)
+
         if src.startswith(attachment_prefix):
             name = src[len(attachment_prefix):]
-            
-            if not name in attachments:
+
+            if name not in attachments:
                 raise InvalidNotebook("missing attachment: {}".format(name))
-            
+
             attachment = attachments[name]
             # we choose vector over raster, and lossless over lossy
             preferred_mime_types = ['image/svg+xml', 'image/png', 'image/jpeg']
@@ -175,8 +202,51 @@ class IPythonRenderer(mistune.Renderer):
             mime_type = preferred_mime_type
             data = attachment[mime_type]
             src = 'data:' + mime_type + ';base64,' + data
+
+        elif embed_images:
+            base64_url = self._src_to_base64(src)
+
+            if base64_url is not None:
+                src = base64_url
+
         return super().image(src, title, text)
 
+    def _src_to_base64(self, src):
+        """Turn the source file into a base64 url.
+
+        :param src: source link of the file.
+        :return: the base64 url or None if the file was not found.
+        """
+        path = self.options.get('path', '')
+        src_path = os.path.join(path, src)
+
+        if not os.path.exists(src_path):
+            return None
+
+        with open(src_path, 'rb') as fobj:
+            mime_type = mimetypes.guess_type(src_path)[0]
+
+            base64_data = base64.b64encode(fobj.read())
+            base64_data = base64_data.replace(b'\n', b'').decode('ascii')
+
+            return 'data:{};base64,{}'.format(mime_type, base64_data)
+
+    def _html_embed_images(self, html):
+        parsed_html = bs4.BeautifulSoup(html, features="html.parser")
+        imgs = parsed_html.find_all('img')
+
+        # Replace img tags's sources by base64 dataurls
+        for img in imgs:
+            if 'src' not in img.attrs:
+                continue
+
+            base64_url = self._src_to_base64(img.attrs['src'])
+
+            if base64_url is not None:
+                img.attrs['src'] = base64_url
+
+        return str(parsed_html)
+
 
 def markdown2html_mistune(source):
     """Convert a markdown string to HTML using mistune"""
